@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 #include <glib.h>
@@ -52,6 +56,8 @@ GtkWidget * get_wg (gchar *name);
 
 GtkWindow * get_win (gchar *name);
 
+void set_wg_bg_color (GtkWidget *widget, gchar *bg_color);
+
 void set_pixmap (gchar *widget, gchar *image);
 
 /* Search for the user directory and create it if not found
