@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 /*
@@ -92,28 +96,10 @@ on_button_fluid_clicked (GtkButton *button, gpointer user_data)
 	tutor_init (TT_FLUID);
 }
 
-G_MODULE_EXPORT void
-on_button_help_clicked (GtkButton *button, gpointer user_data)
-{
-	gtk_widget_show (get_wg ("dialog_info"));
-}
-
 G_MODULE_EXPORT void
 on_button_about_clicked (GtkButton *button, gpointer user_data)
 {
-	gtk_widget_show (get_wg ("aboutdialog_klavaro"));
-}
-
-G_MODULE_EXPORT void
-on_aboutdialog_klavaro_close (GtkDialog *dialog, gint response_id, gpointer user_data)
-{
-	gtk_widget_hide (GTK_WIDGET (dialog));
-}
-
-G_MODULE_EXPORT void
-on_aboutdialog_klavaro_response (GtkDialog *dialog, gint response_id, gpointer user_data)
-{
-	gtk_widget_hide (GTK_WIDGET (dialog));
+	gtk_widget_show (get_wg ("aboutdialog"));
 }
 
 G_MODULE_EXPORT void
@@ -198,16 +184,7 @@ on_window_main_destroy (GtkWidget *obj, gpointer data)
 }
 
 /**********************************************************************
- * 2 - Little nohelp-dialog
- **********************************************************************/
-G_MODULE_EXPORT void
-on_button_info_return_clicked (GtkButton *but, gpointer user_data)
-{
-	gtk_widget_hide (get_wg ("dialog_info"));
-}
-
-/**********************************************************************
- * 3 - Tutor window
+ * 2 - Tutor window
  **********************************************************************/
 
 static void 
@@ -840,7 +817,7 @@ on_entry_mesg_realize (GtkWidget * widget, gpointer user_data)
 }
 
 /**********************************************************************
- * 4 - Top 10 management
+ * 3 - Top 10 management
  **********************************************************************/
 G_MODULE_EXPORT void
 on_combobox_top10_changed (GtkComboBox *cmb, gpointer user_data)
@@ -948,7 +925,7 @@ on_button_top10_close_clicked (GtkButton * button, gpointer user_data)
 }
 
 /**********************************************************************
- * 5 - Keyboard window
+ * 4 - Keyboard window
  **********************************************************************/
 
 G_MODULE_EXPORT void
@@ -1392,7 +1369,7 @@ on_button_hints_close_clicked (GtkButton *but, gpointer user_data)
 }
 
 /**********************************************************************
- * 6 - Charts window
+ * 5 - Charts window
  **********************************************************************/
 
 G_MODULE_EXPORT void
@@ -1533,7 +1510,7 @@ on_databox_hovered (GtkDatabox *dbox, GdkEventMotion *event, gpointer user_data)
 }
 
 /**********************************************************************
- * 7 - Other texts popup
+ * 6 - Other texts popup
  **********************************************************************/
 
 G_MODULE_EXPORT void
@@ -1817,7 +1794,7 @@ on_button_filechooser_cancel_clicked (GtkButton *button, gpointer user_data)
 }
 
 /**********************************************************************
- * 8 - Mangling with the windows positions 
+ * 7 - Mangling with the windows positions 
  **********************************************************************/
 
 G_MODULE_EXPORT void
