@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 /*
@@ -264,18 +268,11 @@ plot_initialize ()
 	gtk_container_add (GTK_CONTAINER (get_wg ("frame_stat")), plot.gtkgrid);
 	g_signal_connect (G_OBJECT (plot.databox), "motion_notify_event", G_CALLBACK (on_databox_hovered), NULL);
 
-	/* Set background not working: FIXME
-	css = gtk_css_provider_new ();
-	gtk_css_provider_load_from_data (css, ".plot_bg {background-color: white;}", -1, NULL);
-	sc = gtk_widget_get_style_context (plot.databox);
-	gtk_style_context_add_provider (sc, GTK_STYLE_PROVIDER (css), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	gtk_style_context_add_class (sc, "plot_bg");
-	 */
 	if (main_altcolor_get_boolean ("colors", "altcolor"))
 		tcolor = main_altcolor_get_string ("colors", "text_intro_bg");
 	else
 		tcolor = main_preferences_get_string ("colors", "text_intro_bg");
-	gtk_databox_background (tcolor); // This is a hack!
+	gtk_databox_set_bg_color (GTK_DATABOX(plot.databox), tcolor);
 
 	/* Y labels
 	 */
