@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 /*
@@ -69,14 +73,15 @@ trans_code_to_country (gchar *code)
 		{"il","ישראל"},
 		{"hr","Hrvatska"},
 		{"hu","Magyarország"},
+		{"id","Indonesia"},
 		{"in","India"},
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
 		{"kk","Қазақстан"},
 		{"kr","대한민국"}, /* Korea */
 		{"no","Norge"},
-		{"pl","Polska"},
 		/* 30 */
+		{"pl","Polska"},
 		{"pk","پاکستان"},
 		{"pt","Portugal"},
 		{"rs","Србија"}, /* Serbia */
@@ -86,8 +91,8 @@ trans_code_to_country (gchar *code)
 		{"sk","Slovensko"},
 		{"tr","Türkiye"},
 		{"ua","Україна"},
-		{"uk","United Kingdom"},
 		/* 40 */
+		{"uk","United Kingdom"},
 		{"us","USA"},
 		{"",""},
 		{"",""},
@@ -97,9 +102,8 @@ trans_code_to_country (gchar *code)
 		{"",""},
 		{"",""},
 		{"",""},
-		{"",""},
 		/* 50 */
-		{"",""},
+		{"",""}
 	};
 
 	for (i = 0; i < COUNTRY_N; i++)
@@ -253,40 +257,39 @@ trans_lang_has_stopmark ()
  * Private auxiliar function
  */
 static gboolean
-trans_lang_get_similar (gchar * test)
+trans_lang_get_similar (gchar ** test)
 {
 	gint i;
 	gchar aux_code_2[3];
 
-	/* Prefer C over en_GB for English variants other than en_GB. (Debian patch 02) */
-	if (g_str_has_prefix (test, "en"))
+	if (*test == NULL)
 	{
-		g_free (test);
-		test = g_strdup ("C");
+		g_warning ("trans_lang_get_similar received NULL lang code");
+		return (FALSE);
+	}
+
+	if (g_str_equal (*test, "C"))
+		return (TRUE);
+
+	/* Prefer C over en_GB for English variants other than en_GB. (Debian patch 02) */
+	if (g_str_has_prefix (*test, "en"))
+	{
+		g_free (*test);
+		*test = g_strdup ("C");
 		return (TRUE);
 	}
 
-	if (g_str_equal (test, "C"))
-		return TRUE;
-
-	strncpy (aux_code_2, test, 2);
+	strncpy (aux_code_2, *test, 2);
 	aux_code_2[2] = '\0';
-
 	for (i = 0; i < lang_num; i++)
 	{
 		if (strstr (lang[i].code, aux_code_2))
 		{
-			g_free (test);
-			test = g_strdup (lang[i].code);
+			g_free (*test);
+			*test = g_strdup (lang[i].code);
 			break;
 		}
 	}
-	if (i == lang_num && g_str_has_prefix (test, "en"))
-	{
-		g_free (test);
-		test = g_strdup ("C");
-		return (TRUE);
-	}
 	return (i == lang_num ? FALSE : TRUE);
 }
 
@@ -296,14 +299,13 @@ trans_lang_get_similar (gchar * test)
 void
 trans_init_language_env ()
 {
-	gchar *tmp_code;
-	gboolean lang_ok;
+	gchar *tmp_code = NULL;
+	gboolean lang_ok = FALSE;
 	gint i;
 
 	/*
 	 * If the language is already set in preferences, just use it
 	 */
-	lang_ok = FALSE;
 	if (main_preferences_exist ("interface", "language"))
 	{
 		lang_ok = TRUE;
@@ -313,6 +315,8 @@ trans_init_language_env ()
 			tmp_code[2] = '\0';
 			if (trans_lang_is_available (tmp_code) == FALSE)
 			{
+				g_free (tmp_code);
+				tmp_code = NULL;
 				lang_ok = FALSE;
 				main_preferences_remove ("interface", "language");
 			}
@@ -330,7 +334,7 @@ trans_init_language_env ()
 		i = 0;
 		while ((tmp_code = g_strdup (g_get_language_names ()[i])))
 		{
-			if (tmp_code[0] == 'C')
+			if (tmp_code[0] == 'C') /* Last one (always!) */
 			{
 				lang_ok = (i == 0 ? TRUE : FALSE);
 				break;
@@ -352,10 +356,11 @@ trans_init_language_env ()
 					lang_ok = (i == 0 ? TRUE : FALSE);
 					break;
 				}
-				lang_ok = trans_lang_get_similar (tmp_code);
+				lang_ok = trans_lang_get_similar (&tmp_code);
 				if (lang_ok == TRUE)
 					break;
-				g_free (tmp_code);
+				if (tmp_code != NULL)
+					g_free (tmp_code);
 				lang_ok = FALSE;
 				i++;
 			}
@@ -364,7 +369,7 @@ trans_init_language_env ()
 		tmp_code = g_win32_getlocale ();
 		lang_ok = trans_lang_is_available (tmp_code);
 		if (lang_ok == FALSE)
-			lang_ok = trans_lang_get_similar (tmp_code);
+			lang_ok = trans_lang_get_similar (&tmp_code);
 #endif
 	}
 	if (tmp_code == NULL)
