@@ -1,14 +1,18 @@
 /**************************************************************************/
 /*  Klavaro - a flexible touch typing tutor                               */
-/*  Copyright (C) from 2005 until 2008 Felipe Castro                      */
-/*  Copyright (C) from 2009 until 2019 The Free Software Foundation       */
+/*  Copyright (C) 2005-2021 Felipe Emmanuel Ferreira de Castro            */
 /*                                                                        */
-/*  This program is free software, licensed under the terms of the GNU    */
-/*  General Public License as published by the Free Software Foundation,  */
-/*  either version 3 of the License, or (at your option) any later        */
-/*  version. You should have received a copy of the GNU General Public    */
-/*  License along with this program. If not,                              */
-/*  see <https://www.gnu.org/licenses/>.                                  */
+/*  This file is part of Klavaro, which is a free software: you can       */
+/*  redistribute it and/or modify it under the terms of the GNU General   */
+/*  Public License as published by the Free Software Foundation, either   */
+/*  version 3 of the License, or (at your option) any later version.      */
+/*                                                                        */
+/*  Klavaro is distributed in the hope that it will be useful,            */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of        */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
+/*  GNU General Public License for more details (in the file COPYING).    */
+/*  You should have received a copy of the GNU General Public License     */
+/*  along with Klavaro.  If not, see <https://www.gnu.org/licenses/>      */
 /**************************************************************************/
 
 /*
@@ -295,8 +299,7 @@ tutor_init (TutorType tt_type)
 
 	gtk_widget_hide (get_wg ("window_main"));
 	gtk_widget_hide (get_wg ("window_keyboard"));
-	gtk_widget_hide (get_wg ("dialog_info"));
-	gtk_widget_hide (get_wg ("aboutdialog_klavaro"));
+	gtk_widget_hide (get_wg ("aboutdialog"));
 	gtk_widget_hide (get_wg ("togglebutton_toomuch_errors"));
 	gtk_widget_show (get_wg ("window_tutor"));
 	gtk_widget_grab_focus (get_wg ("entry_mesg"));
@@ -455,7 +458,6 @@ tutor_update_intro ()
 	gchar *tmp_name;
 	gchar *text;
 	gchar *color_bg;
-	GdkRGBA color;
 	GtkWidget *wg;
 	GtkLabel *wg_label;
 	GtkTextView *wg_text;
@@ -503,9 +505,7 @@ tutor_update_intro ()
 		g_free (color_bg);
 		color_bg = main_altcolor_get_string ("colors", "text_intro_bg");
 	}
-	gdk_rgba_parse (&color, color_bg); 
-	/* FIXME: update deprecated function for background color */
-	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
+	set_wg_bg_color (get_wg ("text_tutor"), color_bg);
 	g_free (color_bg);
 
 	wg = get_wg ("scrolledwindow_tutor_main");
@@ -523,7 +523,6 @@ tutor_update_start ()
 	gchar *tmp_name;
 	gchar *text;
 	gchar *color_bg;
-	GdkRGBA color;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
 	GtkTextIter start;
@@ -584,9 +583,7 @@ tutor_update_start ()
 		g_free (color_bg);
 		color_bg = main_altcolor_get_string ("colors", "char_untouched_bg");
 	}
-	/* FIXME: update deprecated function for background color */
-	gdk_rgba_parse (&color, color_bg);
-	gtk_widget_override_background_color (get_wg ("text_tutor"), GTK_STATE_FLAG_INSENSITIVE, &color);
+	set_wg_bg_color (get_wg ("text_tutor"), color_bg);
 	g_free (color_bg);
 
 	gtk_text_buffer_get_bounds (buf, &start, &end);
